Index: src/x64/macro-assembler-x64.h |
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h |
index 124153b52d653a54d8a2c367031319a748bbde30..9d5d2a31c5ceee61652cd923ca83e8a13d1388ca 100644 |
--- a/src/x64/macro-assembler-x64.h |
+++ b/src/x64/macro-assembler-x64.h |
@@ -1354,14 +1354,14 @@ class MacroAssembler: public Assembler { |
void CheckEnumCache(Register null_value, |
Label* call_runtime); |
// AllocationSiteInfo support. Arrays may have an associated |
// AllocationSiteInfo object that can be checked for in order to pretransition |
// to another type. |
// On entry, receiver_reg should point to the array object. |
// scratch_reg gets clobbered. |
// If allocation info is present, condition flags are set to equal |
- void TestJSArrayForAllocationSiteInfo(Register receiver_reg, |
- Register scratch_reg); |
+ void TestJSArrayForAllocationMemento(Register receiver_reg, |
+ Register scratch_reg); |
private: |
// Order general registers are pushed by Pushad. |
@@ -1354,14 +1354,14 @@ class MacroAssembler: public Assembler { |
void CheckEnumCache(Register null_value, |
Label* call_runtime); |
- // AllocationSiteInfo support. Arrays may have an associated |
- // AllocationSiteInfo object that can be checked for in order to pretransition |
+ // AllocationMemento support. Arrays may have an associated |
+ // AllocationMemento object that can be checked for in order to pretransition |
// to another type. |
// On entry, receiver_reg should point to the array object. |